==> spip_3.2.11.orig.tar.xz: plugins-dist/forum/lang/forum_de.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=de
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucun_message_forum' => 'Kein Beitrag',

	// B
	'bouton_radio_articles_futurs' => 'nur für neue Artikel (hat keine Auswirkungen auf die Datenbank).',
	'bouton_radio_articles_tous' => 'für ausnahmslos alle Artikel.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'nur für Artikel mit aktiviertem Forum.',
	'bouton_radio_enregistrement_obligatoire' => 'Obligatorische Anmeldung (Besucher müssen sich mit einer gültigen E-Mail Adresse anmelden, um Forumsbeiträge schreiben zu können).',
	'bouton_radio_moderation_priori' => 'Vorgeschaltete Moderation (Die Benutzerkommentare werden erst nach Bestätigung durch einen Administrator sichtbar). ',
	'bouton_radio_modere_abonnement' => 'Mit Anmeldung',
	'bouton_radio_modere_posteriori' => 'Nachträgliche Moderation',
	'bouton_radio_modere_priori' => 'Vorgeschaltete Moderation',
	'bouton_radio_publication_immediate' => 'Sofortige Veröffentlichung von Beiträgen (sie werden sofort nach dem Absenden angezeigt und können von Administratoren nachträglich gelöscht werden).',

	// D
	'documents_interdits_forum' => 'Dokumente sind im Forum verboten.',

	// E
	'erreur_enregistrement_message' => 'Fehler: Ihr Beitrag konnte nicht gespeichert werden.',
	'extensions_autorisees' => 'Erlaubte Endungen:',
	'extensions_autorisees_toutes' => 'Alle',

	// F
	'form_pet_message_commentaire' => 'Eine Nachricht, ein Kommentar?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Sie haben keinen Zugang mehr zu diesen Foren.',
	'forum_attention_dix_caracteres' => '<b>Achtung!</b> Ihr Beitrag ist muss mindestens 10 Zeichen lang sein.',
	'forum_attention_message_non_poste' => 'Pozor, neposlali ste svoj príspevok!',
	'forum_attention_nb_caracteres_mini' => '<b>Achtung!</b> ihr Beitrag muss mindestens @min@ Zeichen enthalten.',
	'forum_attention_trois_caracteres' => '<b>Achtung!</b> Ihr Titel muss mindestens drei Zeichen lang sein.',
	'forum_attention_trop_caracteres' => '<b>Achtung!</b> Ihr Beitrag ist zu lang (@compte@ Zeichen). Damit er gespeichert werden kann, darf er maximal @max@ Zeichen lang sein.',
	'forum_avez_selectionne' => 'Sie haben ausgewählt:',
	'forum_cliquer_retour' => '<a href=\'@retour_forum@\'>Weiter</a>',
	'forum_envoyer' => 'Abschicken',
	'forum_forum' => 'Forum',
	'forum_info_modere' => 'Dieses Forum ist moderiert. Ihr Beitrag erscheint erst nach Freischaltung durch einen Administrator der Website.',
	'forum_lien_hyper' => 'Hyperlink',
	'forum_message' => 'Ihr Beitrag',
	'forum_message_definitif' => 'Beitrag fertiggestellt: Endgültig eintragen.',
	'forum_message_trop_long' => 'Ihr Beitrag ist zu lang. Sie können maximal 20.000 Zeichen schreiben.',
	'forum_ne_repondez_pas' => 'Antworten Sie nicht auf diese Mail, sondern im Forum mit dieser Adresse:',
	'forum_page_url' => '(Wenn sich Ihr Beitrag auf einen Artikel im Internet oder auf eine Seite mit Zusatzinformationen bezieht, geben Sie hier bitte den Titel der Seite und ihre Adresse bzw. URL an.)',
	'forum_permalink' => 'Permalink des Beitrags',
	'forum_poste_par' => 'Beitrag von @parauteur@ als Antwort auf den Artikel « @titre@ ».',
	'forum_poste_par_court' => 'Nachricht gesendet@parauteur@.',
	'forum_poste_par_generique' => 'Nachricht gesendet@parauteur@ (@objet@ « @titre@ »).',
	'forum_qui_etes_vous' => 'Wer sind Sie?',
	'forum_saisie_texte_info' => 'In diesem Formular können Sie die SPIP-Tags <code>[-&gt;url] {{gras}} {italique} &lt;quote&gt; &lt;code&gt;</code>sowie die HTML-Codes <code>&lt;q&gt; &lt;del&gt; &lt;ins&gt;</code> verwenden.Absätze fügen Sie mit Leerzeilen ein.',
	'forum_texte' => 'Text Ihres Beitrags',
	'forum_titre' => 'Titel',
	'forum_url' => 'Ihre Website',
	'forum_valider' => 'Auswahl bestätigen',
	'forum_voir_avant' => 'Vorschau starten',
	'forum_votre_email' => 'Ihr E-Mail Adresse',
	'forum_votre_nom' => 'Ihr Name',
	'forum_vous_enregistrer' => 'Um an diesem Forum teilnehmen zu können, müssen Sie sich anmelden. Bitte tragen Sie weiter unten die Zugangsdaten ein, die Sie per Mail erhalten haben. Wenn Sie noch nicht angemeldet sind, können Sie sich',
	'forum_vous_inscrire' => 'online anmelden.',

	// I
	'icone_bruler_message' => 'Als SPAM markieren',
	'icone_bruler_messages' => 'Als SPAM markieren',
	'icone_legitimer_message' => 'Als erwünscht markieren',
	'icone_poster_message' => 'Nachricht schicken',
	'icone_suivi_forum' => 'Öffentliches Forum: @nb_forums@ Beiträge',
	'icone_suivi_forums' => 'Foren verwalten',
	'icone_supprimer_message' => 'Nachricht löschen',
	'icone_supprimer_messages' => 'Diese Beiträge löschen',
	'icone_valider_message' => 'Beitrag freigeben',
	'icone_valider_messages' => 'Diese Beiträge freischalten',
	'icone_valider_repondre_message' => 'Diesen Beitrag veröffentlichen und beantworten',
	'info_1_message_forum' => '1 Beitrag im Forum',
	'info_activer_forum_public' => 'Um die öffentlichen Foren zu aktivieren, wählen Sie bitte
 den voreingestellten Moderationmodus:',
	'info_appliquer_choix_moderation' => 'Moderationstyp anwenden:',
	'info_config_forums_prive' => 'Im Redaktionsbereich können Sie verschiedene Arten Forum aktivieren:',
	'info_config_forums_prive_admin' => 'Ein Forum nur für Administratoren der Site:',
	'info_config_forums_prive_global' => 'Ein allgemeines Forum für alle Redakteure:',
	'info_config_forums_prive_objets' => 'Ein Forum unter jedem Artikel, Meldung, verlinkten Website, etc.:',
	'info_desactiver_forum_public' => 'Öffentliche Foren abschalten. Es ist immer noch möglich, ein Forum für einen Artikel einzurichten. Für Rubriken, Meldungen, etc. stehen dann keine Foren zur Verfügung.',
	'info_envoi_forum' => 'Forumsbeiträge an Autoren der Artikel schicken',
	'info_fonctionnement_forum' => 'Funktionsweise des Forums:',
	'info_forcer_previsualisation_court' => 'Vorschaue erzwingen',
	'info_forcer_previsualisation_long' => 'Vorschau vor dem Versenden der Nachricht erzwingen',
	'info_forums_liees_mot' => 'Beiträge mit diesem Schlagwort',
	'info_gauche_suivi_forum_2' => 'Die Seite zum <i>Verwalten der Foren</i> hat eine administrative Funktion und dient nicht zum Diskutieren mit den Lesern. Es werden alle Einträge in öffentlichen und internen Foren gezeigt, so dass Sie diese einzeln autorisieren und ablehnen können.',
	'info_liens_syndiques_3' => 'Foren',
	'info_liens_syndiques_4' => 'sind',
	'info_liens_syndiques_5' => 'Forum',
	'info_liens_syndiques_6' => 'ist',
	'info_liens_syndiques_7' => 'wartet auf Freigabe',
	'info_liens_texte' => 'Links im Text des Beitrags',
	'info_liens_titre' => 'Links im Titel des Beitrags',
	'info_mode_fonctionnement_defaut_forum_public' => 'Standardmodus der öffentlichen Foren',
	'info_nb_messages_forum' => '@nb@ Beiträge im Forum',
	'info_option_email' => 'Wenn ein Besucher einen Beitrag im Forum eines Artikels postet, kann SPIP ihn an den Autor des Artikels schicken. Bitte geben Sie für jeden Inhaltstyp an, ob sie diese Funktion nutzen möchten.',
	'info_pas_de_forum' => 'kein Forum',
	'info_question_visiteur_ajout_document_forum' => 'Wenn Sie den Besuchern gestatten, ihren Forumsbeiträgen Dokumente (Töne, Bilder, ...) beizufügen, wählen Sie bitte aus der Liste die erlaubten Formate (z.B. gif, jpg, png, mp3).',
	'info_question_visiteur_ajout_document_forum_format' => 'Wenn Sie alle von SPIP akzeptierten Dateitypen zulassen möchten, geben Sie bitte einen Asterisk (*) ein. Wenn Sie keine Dokumente zulassen möchten, tragen Sie keinen Wert ein.',
	'info_selectionner_message' => 'Beiträge auswählen:',
	'interface_formulaire' => 'Interface als Formular',
	'interface_onglets' => 'Interface mit Reitern',
	'item_activer_forum_administrateur' => 'Admin-Forum aktivieren',
	'item_config_forums_prive_global' => 'Forum der Redakteure aktivieren',
	'item_config_forums_prive_objets' => 'Diese Foren aktivieren',
	'item_desactiver_forum_administrateur' => 'Admin-Forum abschalten',
	'item_non_config_forums_prive_global' => 'Forum der Redakteure abschalten',
	'item_non_config_forums_prive_objets' => 'Diese Foren abschalten',

	// L
	'label_selectionner' => 'Auswählen:',
	'lien_reponse_article' => 'Antwort auf Artikel',
	'lien_reponse_breve_2' => 'Antwort auf Meldung',
	'lien_reponse_message' => 'Beitrag beantworten',
	'lien_reponse_rubrique' => 'Antwort auf Rubrik',
	'lien_reponse_site_reference' => 'Antwort auf verlinkte Website',
	'lien_vider_selection' => 'Auswahl entfernen',

	// M
	'messages_aucun' => 'Kein',
	'messages_meme_auteur' => 'Alle Beiträge dieses Autors',
	'messages_meme_email' => 'Alle Beiträge mit dieser E-Mail',
	'messages_meme_ip' => 'Alle Beiträge von dieser IP',
	'messages_off' => 'Gelöscht',
	'messages_perso' => 'Persönlich',
	'messages_privadm' => 'Administratoren',
	'messages_prive' => 'Privat',
	'messages_privoff' => 'Gelöscht',
	'messages_privrac' => 'Allgemein',
	'messages_prop' => 'Vorgeschlagen',
	'messages_publie' => 'Veröffentlicht',
	'messages_spam' => 'Spam',
	'messages_tous' => 'Alle',

	// O
	'onglet_messages_internes' => 'Interne Nachrichten',
	'onglet_messages_publics' => 'Öffentliche Nachrichten',
	'onglet_messages_vide' => 'Nachrichten ohne Text',

	// R
	'repondre_message' => 'auf diese Nachricht antworten',

	// S
	'statut_off' => 'Gelöscht',
	'statut_original' => 'Original',
	'statut_prop' => 'Vorgeschlagen',
	'statut_publie' => 'Veröffentlicht',
	'statut_spam' => 'Spam',

	// T
	'text_article_propose_publication_forum' => 'Bitte schreiben Sie Ihren Kommentar in das Forum zu diesem Artikel (unten auf der Seite).',
	'texte_en_cours_validation' => 'Diese Artikel, Meldungen und Forumsbeiträge sind zur Veröffentlichung vorgeschlagen',
	'texte_en_cours_validation_forum' => 'Bitte schreiben Sie Ihre Kommentare in die entsprechenden Foren.',
	'texte_messages_publics' => 'Öffentliche Beiträge zu:',
	'titre_cadre_forum_administrateur' => 'Administratorforum',
	'titre_cadre_forum_interne' => 'Internes Forum',
	'titre_config_forums_prive' => 'Forum des Redaktionsbereichs',
	'titre_forum' => 'Forum',
	'titre_forum_suivi' => 'Foren moderieren',
	'titre_page_forum_suivi' => 'Foren moderieren',
	'titre_selection_action' => 'Auswahl',
	'tout_voir' => 'Alle Beiträge anzeigen',

	// V
	'voir_messages_objet' => 'Beiträge anzeigen'
);

==> spip_4.0.4.orig.tar.xz: plugins-dist/forum/lang/forum_de.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=de
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucun_message_forum' => 'Kein Beitrag',

	// B
	'bouton_radio_articles_futurs' => 'nur für neue Artikel (hat keine Auswirkungen auf die Datenbank).',
	'bouton_radio_articles_tous' => 'für ausnahmslos alle Artikel.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'nur für Artikel mit aktiviertem Forum.',
	'bouton_radio_enregistrement_obligatoire' => 'Obligatorische Anmeldung (Besucher müssen sich mit einer gültigen E-Mail Adresse anmelden, um Forumsbeiträge schreiben zu können).',
	'bouton_radio_moderation_priori' => 'Vorgeschaltete Moderation (Die Benutzerkommentare werden erst nach Bestätigung durch einen Administrator sichtbar). ',
	'bouton_radio_modere_abonnement' => 'Mit Anmeldung',
	'bouton_radio_modere_posteriori' => 'Nachträgliche Moderation',
	'bouton_radio_modere_priori' => 'Vorgeschaltete Moderation',
	'bouton_radio_publication_immediate' => 'Sofortige Veröffentlichung von Beiträgen (sie werden sofort nach dem Absenden angezeigt und können von Administratoren nachträglich gelöscht werden).',

	// D
	'documents_interdits_forum' => 'Dokumente sind im Forum verboten.',

	// E
	'erreur_enregistrement_message' => 'Fehler: Ihr Beitrag konnte nicht gespeichert werden.',
	'extensions_autorisees' => 'Erlaubte Endungen:',
	'extensions_autorisees_toutes' => 'Alle',

	// F
	'form_pet_message_commentaire' => 'Eine Nachricht, ein Kommentar?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Sie haben keinen Zugang mehr zu diesen Foren.',
	'forum_attention_dix_caracteres' => '<b>Achtung!</b> Ihr Beitrag ist muss mindestens 10 Zeichen lang sein.',
	'forum_attention_message_non_poste' => 'Pozor, neposlali ste svoj príspevok!',
	'forum_attention_nb_caracteres_mini' => '<b>Achtung!</b> ihr Beitrag muss mindestens @min@ Zeichen enthalten.',
	'forum_attention_trois_caracteres' => '<b>Achtung!</b> Ihr Titel muss mindestens drei Zeichen lang sein.',
	'forum_attention_trop_caracteres' => '<b>Achtung!</b> Ihr Beitrag ist zu lang (@compte@ Zeichen). Damit er gespeichert werden kann, darf er maximal @max@ Zeichen lang sein.',
	'forum_avez_selectionne' => 'Sie haben ausgewählt:',
	'forum_cliquer_retour' => '<a href=\'@retour_forum@\'>Weiter</a>',
	'forum_envoyer' => 'Abschicken',
	'forum_forum' => 'Forum',
	'forum_info_modere' => 'Dieses Forum ist moderiert. Ihr Beitrag erscheint erst nach Freischaltung durch einen Administrator der Website.',
	'forum_lien_hyper' => 'Hyperlink',
	'forum_message' => 'Ihr Beitrag',
	'forum_message_definitif' => 'Beitrag fertiggestellt: Endgültig eintragen.',
	'forum_message_trop_long' => 'Ihr Beitrag ist zu lang. Sie können maximal 20.000 Zeichen schreiben.',
	'forum_ne_repondez_pas' => 'Antworten Sie nicht auf diese Mail, sondern im Forum mit dieser Adresse:',
	'forum_page_url' => '(Wenn sich Ihr Beitrag auf einen Artikel im Internet oder auf eine Seite mit Zusatzinformationen bezieht, geben Sie hier bitte den Titel der Seite und ihre Adresse bzw. URL an.)',
	'forum_permalink' => 'Permalink des Beitrags',
	'forum_poste_par' => 'Beitrag gesendet @parauteur@ als Antwort auf den Artikel « @titre@ ».',
	'forum_poste_par_court' => 'Nachricht gesendet@parauteur@.',
	'forum_poste_par_generique' => 'Nachricht gesendet@parauteur@ (@objet@ « @titre@ »).',
	'forum_qui_etes_vous' => 'Wer sind Sie?',
	'forum_saisie_texte_info' => 'In diesem Formular können Sie die SPIP-Tags <code>[-&gt;url] {{fett}} {kursiv} &lt;quote&gt; &lt;code&gt;</code>sowie die HTML-Codes <code>&lt;q&gt; &lt;del&gt; &lt;ins&gt;</code> verwenden.Absätze fügen Sie mit Leerzeilen ein.',
	'forum_texte' => 'Text Ihres Beitrags',
	'forum_titre' => 'Titel',
	'forum_url' => 'Ihre Website',
	'forum_valider' => 'Auswahl bestätigen',
	'forum_voir_avant' => 'Vorschau starten',
	'forum_votre_email' => 'Ihr E-Mail Adresse',
	'forum_votre_nom' => 'Ihr Name',
	'forum_vous_enregistrer' => 'Um an diesem Forum teilnehmen zu können, müssen Sie sich anmelden. Bitte tragen Sie weiter unten die Zugangsdaten ein, die Sie per Mail erhalten haben. Wenn Sie noch nicht angemeldet sind, können Sie sich',
	'forum_vous_inscrire' => 'online anmelden.',

	// I
	'icone_bruler_message' => 'Als SPAM markieren',
	'icone_bruler_messages' => 'Als SPAM markieren',
	'icone_legitimer_message' => 'Als erwünscht markieren',
	'icone_poster_message' => 'Nachricht schicken',
	'icone_suivi_forum' => 'Öffentliches Forum: @nb_forums@ Beiträge',
	'icone_suivi_forums' => 'Foren verwalten',
	'icone_supprimer_message' => 'Nachricht löschen',
	'icone_supprimer_messages' => 'Diese Beiträge löschen',
	'icone_valider_message' => 'Beitrag freigeben',
	'icone_valider_messages' => 'Diese Beiträge freischalten',
	'icone_valider_repondre_message' => 'Diesen Beitrag veröffentlichen und beantworten',
	'info_1_message_forum' => '1 Beitrag im Forum',
	'info_activer_forum_public' => 'Um die öffentlichen Foren zu aktivieren, wählen Sie bitte
 den voreingestellten Moderationmodus:',
	'info_appliquer_choix_moderation' => 'Moderationstyp anwenden:',
	'info_config_forums_prive' => 'Im Redaktionsbereich können Sie verschiedene Arten Forum aktivieren:',
	'info_config_forums_prive_admin' => 'Ein Forum nur für Administratoren der Site:',
	'info_config_forums_prive_global' => 'Ein allgemeines Forum für alle Redakteure:',
	'info_config_forums_prive_objets' => 'Ein Forum unter jedem Artikel, Meldung, verlinkten Website, etc.:',
	'info_desactiver_forum_public' => 'Öffentliche Foren abschalten. Es ist immer noch möglich, ein Forum für einen Artikel einzurichten. Für Rubriken, Meldungen, etc. stehen dann keine Foren zur Verfügung.',
	'info_envoi_forum' => 'Forumsbeiträge an Autoren der Artikel schicken',
	'info_fonctionnement_forum' => 'Funktionsweise des Forums:',
	'info_forcer_previsualisation_court' => 'Vorschaue erzwingen',
	'info_forcer_previsualisation_long' => 'Vorschau vor dem Versenden der Nachricht erzwingen',
	'info_forums_liees_mot' => 'Beiträge mit diesem Schlagwort',
	'info_gauche_suivi_forum_2' => 'Die Seite zum <i>Verwalten der Foren</i> hat eine administrative Funktion und dient nicht zum Diskutieren mit den Lesern. Es werden alle Einträge in öffentlichen und internen Foren gezeigt, so dass Sie diese einzeln autorisieren und ablehnen können.',
	'info_liens_syndiques_3' => 'Foren',
	'info_liens_syndiques_4' => 'sind',
	'info_liens_syndiques_5' => 'Forum',
	'info_liens_syndiques_6' => 'ist',
	'info_liens_syndiques_7' => 'wartet auf Freigabe',
	'info_liens_texte' => 'Links im Text des Beitrags',
	'info_liens_titre' => 'Links im Titel des Beitrags',
	'info_mode_fonctionnement_defaut_forum_public' => 'Standardmodus der öffentlichen Foren',
	'info_nb_messages_forum' => '@nb@ Beiträge im Forum',
	'info_option_email' => 'Wenn ein Besucher einen Beitrag im Forum eines Artikels postet, kann SPIP ihn an den Autor des Artikels schicken. Bitte geben Sie für jeden Inhaltstyp an, ob sie diese Funktion nutzen möchten.',
	'info_pas_de_forum' => 'kein Forum',
	'info_question_visiteur_ajout_document_forum' => 'Wenn Sie den Besuchern gestatten, ihren Forumsbeiträgen Dokumente (Töne, Bilder, ...) beizufügen, wählen Sie bitte aus der Liste die erlaubten Formate (z.B. gif, jpg, png, mp3).',
	'info_question_visiteur_ajout_document_forum_format' => 'Wenn Sie alle von SPIP akzeptierten Dateitypen zulassen möchten, geben Sie bitte einen Asterisk (*) ein. Wenn Sie keine Dokumente zulassen möchten, tragen Sie keinen Wert ein.',
	'info_selectionner_message' => 'Beiträge auswählen:',
	'interface_formulaire' => 'Interface als Formular',
	'interface_onglets' => 'Interface mit Reitern',
	'item_activer_forum_administrateur' => 'Admin-Forum aktivieren',
	'item_config_forums_prive_global' => 'Forum der Redakteure aktivieren',
	'item_config_forums_prive_objets' => 'Diese Foren aktivieren',
	'item_desactiver_forum_administrateur' => 'Admin-Forum abschalten',
	'item_non_config_forums_prive_global' => 'Forum der Redakteure abschalten',
	'item_non_config_forums_prive_objets' => 'Diese Foren abschalten',

	// L
	'label_selectionner' => 'Auswählen:',
	'lien_reponse_article' => 'Antwort auf Artikel',
	'lien_reponse_breve_2' => 'Antwort auf Meldung',
	'lien_reponse_message' => 'Beitrag beantworten',
	'lien_reponse_rubrique' => 'Antwort auf Rubrik',
	'lien_reponse_site_reference' => 'Antwort auf verlinkte Website',
	'lien_vider_selection' => 'Auswahl entfernen',

	// M
	'messages_aucun' => 'Kein',
	'messages_meme_auteur' => 'Alle Beiträge dieses Autors',
	'messages_meme_email' => 'Alle Beiträge mit dieser E-Mail',
	'messages_meme_ip' => 'Alle Beiträge von dieser IP',
	'messages_off' => 'Gelöscht',
	'messages_perso' => 'Persönlich',
	'messages_privadm' => 'Administratoren',
	'messages_prive' => 'Privat',
	'messages_privoff' => 'Gelöscht',
	'messages_privrac' => 'Allgemein',
	'messages_prop' => 'Vorgeschlagen',
	'messages_publie' => 'Veröffentlicht',
	'messages_spam' => 'Spam',
	'messages_tous' => 'Alle',

	// O
	'onglet_messages_internes' => 'Interne Nachrichten',
	'onglet_messages_publics' => 'Öffentliche Nachrichten',
	'onglet_messages_vide' => 'Nachrichten ohne Text',

	// R
	'repondre_message' => 'auf diese Nachricht antworten',

	// S
	'statut_off' => 'Gelöscht',
	'statut_original' => 'Original',
	'statut_prop' => 'Vorgeschlagen',
	'statut_publie' => 'Veröffentlicht',
	'statut_spam' => 'Spam',

	// T
	'text_article_propose_publication_forum' => 'Bitte schreiben Sie Ihren Kommentar in das Forum zu diesem Artikel (unten auf der Seite).',
	'texte_en_cours_validation' => 'Diese Artikel, Meldungen und Forumsbeiträge sind zur Veröffentlichung vorgeschlagen',
	'texte_en_cours_validation_forum' => 'Bitte schreiben Sie Ihre Kommentare in die entsprechenden Foren.',
	'texte_messages_publics' => 'Öffentliche Beiträge zu:',
	'titre_cadre_forum_administrateur' => 'Administratorforum',
	'titre_cadre_forum_interne' => 'Internes Forum',
	'titre_config_forums_prive' => 'Forum des Redaktionsbereichs',
	'titre_forum' => 'Forum',
	'titre_forum_suivi' => 'Foren moderieren',
	'titre_page_forum_suivi' => 'Foren moderieren',
	'titre_selection_action' => 'Auswahl',
	'tout_voir' => 'Alle Beiträge anzeigen',

	// V
	'voir_messages_objet' => 'Beiträge anzeigen'
);
